aboutsummaryrefslogtreecommitdiffstats
path: root/libavfilter/avf_avectorscope.c
diff options
context:
space:
mode:
authorPaul B Mahol <onemda@gmail.com>2013-09-14 12:11:22 +0000
committerPaul B Mahol <onemda@gmail.com>2013-09-14 12:11:22 +0000
commit7d8939a0ff7128268a6fc21d9f759ca1ff4d663e (patch)
treeff4fd70a55d1eda414f8e936cbff91507a3e9b45 /libavfilter/avf_avectorscope.c
parent8134edf3eb1a2479462f107e160d6f3c29853c46 (diff)
downloadandroid_external_ffmpeg-7d8939a0ff7128268a6fc21d9f759ca1ff4d663e.tar.gz
android_external_ffmpeg-7d8939a0ff7128268a6fc21d9f759ca1ff4d663e.tar.bz2
android_external_ffmpeg-7d8939a0ff7128268a6fc21d9f759ca1ff4d663e.zip
avfilter/avf_avectorscope: improve description
Signed-off-by: Paul B Mahol <onemda@gmail.com>
Diffstat (limited to 'libavfilter/avf_avectorscope.c')
-rw-r--r--libavfilter/avf_avectorscope.c4
1 files changed, 2 insertions, 2 deletions
diff --git a/libavfilter/avf_avectorscope.c b/libavfilter/avf_avectorscope.c
index c22504e582..73c5934e34 100644
--- a/libavfilter/avf_avectorscope.c
+++ b/libavfilter/avf_avectorscope.c
@@ -20,7 +20,7 @@
/**
* @file
* audio to video multimedia vector scope filter
*/
#include "libavutil/avassert.h"
@@ -263,7 +263,7 @@ static const AVFilterPad audiovectorscope_outputs[] = {
AVFilter avfilter_avf_avectorscope = {
.name = "avectorscope",
- .description = NULL_IF_CONFIG_SMALL("Display audio vector scope."),
+ .description = NULL_IF_CONFIG_SMALL("Convert input audio to vectorscope video output."),
.uninit = uninit,
.query_formats = query_formats,
.priv_size = sizeof(AudioVectorScopeContext),
@@ -20,7 +20,7 @@
/**
* @file
- * audio to video multimedia vector scope filter
+ * audio to video multimedia vectorscope filter
*/
#include "libavutil/avassert.h"